@@ -1,7 +1,7 @@
 #![allow(clippy::disallowed_names)]
-use std::collections::HashMap;
 #[cfg(all(unix, not(feature = "tokio"), feature = "p2p"))]
 use std::os::unix::net::UnixStream;
+use std::{collections::HashMap, time::Duration};
 #[cfg(all(unix, feature = "tokio", feature = "p2p"))]
 use tokio::net::UnixStream;
 
@@ -24,8 +24,7 @@ use zvariant::{DeserializeDict, Optional, OwnedValue, SerializeDict, Str, Type,
 use zbus::{
     connection, interface,
     message::Header,
-    object_server::{InterfaceRef, SignalContext},
-    proxy,
+    object_server::{InterfaceRef, SignalEmitter},
     proxy::CacheProperties,
     Connection, ObjectServer,
 };
@@ -52,110 +51,6 @@ pub struct RefType<'a> {
     field1: Str<'a>,
 }
 
-#[proxy(assume_defaults = true, gen_blocking = true)]
-trait MyIface {
-    fn ping(&self) -> zbus::Result<u32>;
-
-    fn quit(&self) -> zbus::Result<()>;
-
-    fn test_header(&self) -> zbus::Result<()>;
-
-    fn test_error(&self) -> zbus::Result<()>;
-
-    fn test_single_struct_arg(&self, arg: ArgStructTest) -> zbus::Result<()>;
-
-    fn test_single_struct_ret(&self) -> zbus::Result<ArgStructTest>;
-
-    fn test_multi_ret(&self) -> zbus::Result<(i32, String)>;
-
-    fn test_response_notify(&self) -> zbus::Result<String>;
-
-    fn test_hashmap_return(&self) -> zbus::Result<HashMap<String, String>>;
-
-    fn create_obj(&self, key: &str) -> zbus::Result<()>;
-
-    fn destroy_obj(&self, key: &str) -> zbus::Result<()>;
-
-    #[cfg(feature = "option-as-array")]
-    // Optional params and return values.
-    fn optional_args(&self, key: Option<&str>) -> zbus::Result<Option<String>>;
-
-    #[zbus(property)]
-    fn count(&self) -> zbus::Result<u32>;
-
-    #[zbus(property)]
-    fn set_count(&self, count: u32) -> zbus::Result<()>;
-
-    #[zbus(property)]
-    fn hash_map(&self) -> zbus::Result<HashMap<String, String>>;
-
-    #[zbus(property)]
-    fn address_data(&self) -> zbus::Result<IP4Adress>;
-
-    #[zbus(property)]
-    fn set_address_data(&self, addr: IP4Adress) -> zbus::Result<()>;
-
-    #[zbus(property)]
-    fn address_data2(&self) -> zbus::Result<IP4Adress>;
-
-    #[zbus(property)]
-    fn str_prop(&self) -> zbus::Result<String>;
-
-    #[zbus(property)]
-    fn set_str_prop(&self, str_prop: &str) -> zbus::Result<()>;
-
-    #[zbus(property)]
-    fn ref_type(&self) -> zbus::Result<RefType<'_>>;
-
-    #[zbus(property)]
-    fn set_ref_type(&self, ref_type: RefType<'_>) -> zbus::Result<()>;
-
-    #[zbus(property)]
-    fn fail_property(&self) -> zbus::Result<u32>;
-
-    #[zbus(property)]
-    fn optional_property(&self) -> zbus::Result<Optional<u32>>;
-
-    #[zbus(no_reply)]
-    fn test_no_reply(&self) -> zbus::Result<()>;
-
-    #[zbus(no_autostart)]
-    fn test_no_autostart(&self) -> zbus::Result<()>;
-
-    #[zbus(allow_interactive_auth)]
-    fn test_interactive_auth(&self) -> zbus::Result<()>;
-
-    #[zbus(property)]
-    fn emits_changed_default(&self) -> zbus::Result<u32>;
-
-    #[zbus(property)]
-    fn set_emits_changed_default(&self, count: u32) -> zbus::Result<()>;
-
-    #[zbus(property(emits_changed_signal = "true"))]
-    fn emits_changed_true(&self) -> zbus::Result<u32>;
-
-    #[zbus(property)]
-    fn set_emits_changed_true(&self, count: u32) -> zbus::Result<()>;
-
-    #[zbus(property(emits_changed_signal = "invalidates"))]
-    fn emits_changed_invalidates(&self) -> zbus::Result<u32>;
-
-    #[zbus(property)]
-    fn set_emits_changed_invalidates(&self, count: u32) -> zbus::Result<()>;
-
-    #[zbus(property(emits_changed_signal = "const"))]
-    fn emits_changed_const(&self) -> zbus::Result<u32>;
-
-    #[zbus(property)]
-    fn set_emits_changed_const(&self, count: u32) -> zbus::Result<()>;
-
-    #[zbus(property(emits_changed_signal = "false"))]
-    fn emits_changed_false(&self) -> zbus::Result<u32>;
-
-    #[zbus(property)]
-    fn set_emits_changed_false(&self, count: u32) -> zbus::Result<()>;
-}
-
 #[derive(Debug, Clone)]
 enum NextAction {
     Quit,
@@ -164,7 +59,7 @@ enum NextAction {
 }
 
 #[derive(Debug)]
-struct MyIfaceImpl {
+struct MyIface {
     next_tx: Sender<NextAction>,
     count: u32,
     emits_changed_default: u32,
@@ -174,7 +69,7 @@ struct MyIfaceImpl {
     emits_changed_false: u32,
 }
 
-impl MyIfaceImpl {
+impl MyIface {
     fn new(next_tx: Sender<NextAction>) -> Self {
         Self {
             next_tx,
@@ -189,7 +84,7 @@ impl MyIfaceImpl {
 }
 
 /// Custom D-Bus error type.
-#[derive(Debug, DBusError)]
+#[derive(Debug, DBusError, PartialEq)]
 #[zbus(prefix = "org.freedesktop.MyIface.Error")]
 enum MyIfaceError {
     SomethingWentWrong(String),
@@ -197,13 +92,17 @@ enum MyIfaceError {
     ZBus(zbus::Error),
 }
 
-#[interface(interface = "org.freedesktop.MyIface")]
-impl MyIfaceImpl {
+#[interface(
+    interface = "org.freedesktop.MyIface",
+    proxy(gen_blocking = true, assume_defaults = true, visibility = "pub(self)")
+)]
+impl MyIface {
     #[instrument]
-    async fn ping(&mut self, #[zbus(signal_context)] ctxt: SignalContext<'_>) -> u32 {
+    async fn ping(&mut self, #[zbus(signal_emitter)] emitter: SignalEmitter<'_>) -> u32 {
         self.count += 1;
         if self.count % 3 == 0 {
-            MyIfaceImpl::alert_count(&ctxt, self.count)
+            emitter
+                .alert_count(self.count)
                 .await
                 .expect("Failed to emit signal");
             debug!("emitted `AlertCount` signal.");
@@ -245,7 +144,7 @@ impl MyIfaceImpl {
         #[zbus(header)] header: Header<'_>,
     ) -> zbus::fdo::Result<()> {
         debug!("`TestSingleStructArg` called.");
-        assert_eq!(header.signature().unwrap(), "(is)");
+        assert_eq!(header.signature(), "(is)");
         assert_eq!(arg.foo, 1);
         assert_eq!(arg.bar, "TestString");
 
@@ -272,17 +171,17 @@ impl MyIfaceImpl {
     fn test_response_notify(
         &self,
         #[zbus(connection)] conn: &Connection,
-        #[zbus(signal_context)] ctxt: SignalContext<'_>,
+        #[zbus(signal_emitter)] emitter: SignalEmitter<'_>,
     ) -> zbus::fdo::Result<ResponseDispatchNotifier<String>> {
         debug!("`TestResponseNotify` called.");
         let (response, listener) = ResponseDispatchNotifier::new(String::from("Meaning of life"));
-        let ctxt = ctxt.to_owned();
+        let emitter = emitter.to_owned();
         conn.executor()
             .spawn(
                 async move {
                     listener.await;
 
-                    Self::test_response_notified(ctxt).await.unwrap();
+                    Self::test_response_notified(emitter).await.unwrap();
                 },
                 "TestResponseNotify",
             )
@@ -292,7 +191,7 @@ impl MyIfaceImpl {
     }
 
     #[zbus(signal)]
-    async fn test_response_notified(ctxt: SignalContext<'_>) -> zbus::Result<()>;
+    async fn test_response_notified(emitter: SignalEmitter<'_>) -> zbus::Result<()>;
 
     #[instrument]
     async fn test_hashmap_return(&self) -> zbus::fdo::Result<HashMap<String, String>> {
@@ -305,9 +204,12 @@ impl MyIfaceImpl {
     }
 
     #[instrument]
-    async fn create_obj(&self, key: String) {
+    async fn create_obj(&self, key: &str) {
         debug!("`CreateObj` called.");
-        self.next_tx.send(NextAction::CreateObj(key)).await.unwrap();
+        self.next_tx
+            .send(NextAction::CreateObj(key.into()))
+            .await
+            .unwrap();
     }
 
     #[instrument]
@@ -320,17 +222,17 @@ impl MyIfaceImpl {
         object_server
             .at(
                 format!("/zbus/test/{key}"),
-                MyIfaceImpl::new(self.next_tx.clone()),
+                MyIface::new(self.next_tx.clone()),
             )
             .await
             .unwrap();
     }
 
     #[instrument]
-    async fn destroy_obj(&self, key: String) {
+    async fn destroy_obj(&self, key: &str) {
         debug!("`DestroyObj` called.");
         self.next_tx
-            .send(NextAction::DestroyObj(key))
+            .send(NextAction::DestroyObj(key.into()))
             .await
             .unwrap();
     }
@@ -360,6 +262,47 @@ impl MyIfaceImpl {
         self.count
     }
 
+    // This is a write-only property.
+    // It actually is equivalent to `set_count` above.
+    #[instrument]
+    #[zbus(property)]
+    fn set_count2(&mut self, val: u32) -> zbus::fdo::Result<()> {
+        debug!("`Count` setter called from a write-only property.");
+        self.set_count(val)
+    }
+
+    #[instrument]
+    #[zbus(property)]
+    fn test_header_prop(
+        &self,
+        #[zbus(header)] header: Option<Header<'_>>,
+        #[zbus(connection)] connection: &Connection,
+        #[zbus(object_server)] object_server: &ObjectServer,
+        #[zbus(signal_emitter)] emitter: SignalEmitter<'_>,
+    ) -> bool {
+        debug!(
+            "`TestHeaderProp` getter called, header: {:?}, connection: {:?}, object_server: {:?}, emitter: {:?}",
+            header, connection, object_server, emitter
+        );
+        header.is_some()
+    }
+
+    #[instrument]
+    #[zbus(property)]
+    fn set_test_header_prop(
+        &self,
+        value: bool,
+        #[zbus(header)] header: Option<Header<'_>>,
+        #[zbus(connection)] connection: &Connection,
+        #[zbus(object_server)] object_server: &ObjectServer,
+        #[zbus(signal_emitter)] emitter: SignalEmitter<'_>,
+    ) {
+        debug!("`TestHeaderProp` setter called, value: {}, header: {:?}, connection: {:?}, object_server: {:?}, emitter: {:?}",
+            value, header, connection, object_server, emitter
+        );
+        assert!(header.is_some());
+    }
+
     #[instrument]
     #[zbus(property)]
     async fn hash_map(&self) -> HashMap<String, String> {
@@ -441,6 +384,7 @@ impl MyIfaceImpl {
     }
 
     #[instrument]
+    #[zbus(proxy(no_reply))]
     fn test_no_reply(&self, #[zbus(header)] header: Header<'_>) {
         debug!("`TestNoReply` called");
         assert_eq!(header.message_type(), zbus::message::Type::MethodCall);
@@ -451,6 +395,7 @@ impl MyIfaceImpl {
     }
 
     #[instrument]
+    #[zbus(proxy(no_autostart))]
     fn test_no_autostart(&self, #[zbus(header)] header: Header<'_>) {
         debug!("`TestNoAutostart` called");
         assert_eq!(header.message_type(), zbus::message::Type::MethodCall);
@@ -461,6 +406,7 @@ impl MyIfaceImpl {
     }
 
     #[instrument]
+    #[zbus(proxy(allow_interactive_auth))]
     fn test_interactive_auth(&self, #[zbus(header)] header: Header<'_>) {
         debug!("`TestInteractiveAuth` called");
         assert_eq!(header.message_type(), zbus::message::Type::MethodCall);
@@ -471,7 +417,7 @@ impl MyIfaceImpl {
     }
 
     #[zbus(signal)]
-    async fn alert_count(ctxt: &SignalContext<'_>, val: u32) -> zbus::Result<()>;
+    async fn alert_count(emitter: &SignalEmitter<'_>, val: u32) -> zbus::Result<()>;
 
     #[instrument]
     #[zbus(property)]
@@ -547,6 +493,12 @@ impl MyIfaceImpl {
         self.emits_changed_false = val;
         Ok(())
     }
+
+    async fn never_return(&self) {
+        debug!("`NeverReturn` called.");
+
+        std::future::pending::<()>().await;
+    }
 }
 
 fn check_hash_map(map: HashMap<String, String>) {
@@ -564,13 +516,18 @@ fn check_ipv4_address(address: IP4Adress) {
     );
 }
 
+fn check_ipv4_address_hashmap(address: HashMap<String, OwnedValue>) {
+    assert_eq!(**address.get("address").unwrap(), Value::from("127.0.0.1"));
+    assert_eq!(**address.get("prefix").unwrap(), Value::from(1234u32));
+}
+
 #[instrument]
 async fn my_iface_test(conn: Connection, event: Event) -> zbus::Result<u32> {
     debug!("client side starting..");
     // Use low-level API for `TestResponseNotify` because we need to ensure that the signal is
     // always received after the response.
     let mut stream = MessageStream::from(&conn);
-    let method = Message::method("/org/freedesktop/MyService", "TestResponseNotify")?
+    let method = Message::method_call("/org/freedesktop/MyService", "TestResponseNotify")?
         .interface("org.freedesktop.MyIface")?
         .destination("org.freedesktop.MyService")?
         .build(&())?;
@@ -626,6 +583,16 @@ async fn my_iface_test(conn: Connection, event: Event) -> zbus::Result<u32> {
         .build()
         .await?;
     debug!("Created: {:?}", proxy);
+
+    // First let's call a non-existent method. It should immediately fail.
+    // There was a regression where object server would just not reply in this case:
+    // https://github.com/dbus2/zbus/issues/905
+    assert!(proxy
+        .inner()
+        .call::<_, _, ()>("NonExistantMethod", &())
+        .await
+        .is_err());
+
     let props_proxy = zbus::fdo::PropertiesProxy::builder(&conn)
         .destination("org.freedesktop.MyService")?
         .path("/org/freedesktop/MyService")?
@@ -650,9 +617,17 @@ async fn my_iface_test(conn: Connection, event: Event) -> zbus::Result<u32> {
     drop(props_changed_stream);
 
     proxy.ping().await?;
+    proxy.set_test_header_prop(true).await?;
+    assert!(proxy.test_header_prop().await?);
     assert_eq!(proxy.count().await?, 1);
     assert_eq!(proxy.cached_count()?, None);
 
+    // Test that properties can be set.
+    proxy.set_count(8888).await?;
+    assert_eq!(proxy.count().await?, 8888);
+    proxy.set_count2(1).await?;
+    assert_eq!(proxy.count().await?, 1);
+
     proxy.test_header().await?;
     proxy
         .test_single_struct_arg(ArgStructTest {
@@ -660,6 +635,13 @@ async fn my_iface_test(conn: Connection, event: Event) -> zbus::Result<u32> {
             bar: "TestString".into(),
         })
         .await?;
+
+    proxy.test_error().await.unwrap_err();
+    assert_eq!(
+        proxy.test_custom_error().await.unwrap_err(),
+        MyIfaceError::SomethingWentWrong("oops".to_string())
+    );
+
     check_hash_map(proxy.test_hashmap_return().await?);
     check_hash_map(proxy.hash_map().await?);
     proxy
@@ -670,7 +652,7 @@ async fn my_iface_test(conn: Connection, event: Event) -> zbus::Result<u32> {
         .await?;
     proxy.set_str_prop("This is an str ref").await?;
     check_ipv4_address(proxy.address_data().await?);
-    check_ipv4_address(proxy.address_data2().await?);
+    check_ipv4_address_hashmap(proxy.address_data2().await?);
 
     proxy.test_no_reply().await?;
     proxy.test_no_autostart().await?;
@@ -681,7 +663,7 @@ async fn my_iface_test(conn: Connection, event: Event) -> zbus::Result<u32> {
         err.unwrap_err(),
         zbus::Error::FDO(Box::new(zbus::fdo::Error::UnknownProperty(
             "FailProperty".into()
-        )))
+        ))),
     );
 
     assert_eq!(proxy.optional_property().await?, Some(42).into());
@@ -707,14 +689,14 @@ async fn my_iface_test(conn: Connection, event: Event) -> zbus::Result<u32> {
 
         if method.name() == "TestSingleStructRet" {
             assert_eq!(args.len(), 1);
-            assert_eq!(out_args.next().unwrap().ty().signature(), "(is)");
+            assert_eq!(out_args.next().unwrap().ty(), "(is)");
             assert!(out_args.next().is_none());
         } else {
             assert_eq!(args.len(), 2);
             let foo = out_args.find(|a| a.name() == Some("foo")).unwrap();
-            assert_eq!(foo.ty().signature(), "i");
+            assert_eq!(foo.ty(), "i");
             let bar = out_args.find(|a| a.name() == Some("bar")).unwrap();
-            assert_eq!(bar.ty().signature(), "s");
+            assert_eq!(bar.ty(), "s");
         }
     }
     // build-time check to see if macro is doing the right thing.
@@ -770,7 +752,7 @@ async fn my_iface_test(conn: Connection, event: Event) -> zbus::Result<u32> {
         .build()
         .await?;
     debug!("Created: {:?}", my_obj_proxy);
-    my_obj_proxy.receive_count_changed().await;
+    let mut stream = my_obj_proxy.receive_count_changed().await;
     // Calling this after creating the stream was panicking if the property doesn't get cached
     // before the call (MR !460).
     my_obj_proxy.cached_count()?;
@@ -782,6 +764,16 @@ async fn my_iface_test(conn: Connection, event: Event) -> zbus::Result<u32> {
     );
     my_obj_proxy.ping().await?;
 
+    // The stream should first yield the current value.
+    assert_eq!(stream.next().await.unwrap().get().await?, 0);
+    for test_case in [55, 66, 77, 88] {
+        let (value, _) = futures_util::try_join!(
+            async { stream.next().await.unwrap().get().await },
+            my_obj_proxy.set_count(test_case)
+        )?;
+        assert_eq!(test_case, value);
+    }
+
     let mut ifaces_removed_stream = obj_manager_proxy.receive_interfaces_removed().await?;
     debug!("Created: {:?}", ifaces_removed_stream);
     // Must process in parallel, so the stream listener does not block receiving
@@ -800,7 +792,7 @@ async fn my_iface_test(conn: Connection, event: Event) -> zbus::Result<u32> {
 
     let args = ifaces_removed.args()?;
     assert_eq!(args.object_path(), "/zbus/test/MyObj");
-    assert_eq!(args.interfaces(), &["org.freedesktop.MyIface"]);
+    assert_eq!(args.interfaces().as_ref(), &["org.freedesktop.MyIface"]);
 
     assert!(my_obj_proxy.inner().introspect().await.is_err());
     assert!(my_obj_proxy.ping().await.is_err());
@@ -830,10 +822,7 @@ async fn my_iface_test(conn: Connection, event: Event) -> zbus::Result<u32> {
     let changed = props_changed.next().await.unwrap();
     let expected_property_key = "EmitsChangedDefault";
     let args = changed.args()?;
-    assert_eq!(
-        args.invalidated_properties(),
-        &vec![expected_property_key.to_string()]
-    );
+    assert!(args.invalidated_properties().is_empty());
 
     let changed_prop_key = *args.changed_properties().keys().next().unwrap();
     assert_eq!(changed_prop_key, expected_property_key);
@@ -843,6 +832,7 @@ async fn my_iface_test(conn: Connection, event: Event) -> zbus::Result<u32> {
         <&Value as TryInto<u32>>::try_into(changed_value).unwrap(),
         expected_property_value
     );
+    assert!(args.invalidated_properties().is_empty());
 
     proxy
         .set_emits_changed_true(expected_property_value)
@@ -850,10 +840,7 @@ async fn my_iface_test(conn: Connection, event: Event) -> zbus::Result<u32> {
     let changed = props_changed.next().await.unwrap();
     let expected_property_key = "EmitsChangedTrue";
     let args = changed.args()?;
-    assert_eq!(
-        args.invalidated_properties(),
-        &vec![expected_property_key.to_string()]
-    );
+    assert!(args.invalidated_properties().is_empty());
 
     let changed_prop_key = *args.changed_properties().keys().next().unwrap();
     assert_eq!(changed_prop_key, expected_property_key);
@@ -863,6 +850,7 @@ async fn my_iface_test(conn: Connection, event: Event) -> zbus::Result<u32> {
         <&Value as TryInto<u32>>::try_into(changed_value).unwrap(),
         expected_property_value
     );
+    assert!(args.invalidated_properties().is_empty());
 
     proxy
         .set_emits_changed_invalidates(expected_property_value)
@@ -874,7 +862,7 @@ async fn my_iface_test(conn: Connection, event: Event) -> zbus::Result<u32> {
         args.invalidated_properties(),
         &vec![expected_property_key.to_string()]
     );
-    assert_eq!(args.changed_properties().keys().len(), 0);
+    assert!(args.changed_properties().is_empty());
 
     // First set a property for which we don't expect a signal
     // then set a property for which we do (and we checked above
@@ -893,6 +881,8 @@ async fn my_iface_test(conn: Connection, event: Event) -> zbus::Result<u32> {
         args.invalidated_properties(),
         &vec![unexpected_property_key.to_string()]
     );
+    assert!(!args.changed_properties().is_empty());
+    assert!(args.invalidated_properties().is_empty());
 
     proxy
         .set_emits_changed_false(expected_property_value)
@@ -907,8 +897,24 @@ async fn my_iface_test(conn: Connection, event: Event) -> zbus::Result<u32> {
         args.invalidated_properties(),
         &vec![unexpected_property_key.to_string()]
     );
+    assert!(!args.changed_properties().is_empty());
+    assert!(args.invalidated_properties().is_empty());
+
+    // Test method timeout
+    assert!(
+        conn.method_timeout().is_some(),
+        "method timeout should be set"
+    );
+    match proxy.never_return().await {
+        Err(Error::InputOutput(e)) if e.kind() == std::io::ErrorKind::TimedOut => {}
+        r => panic!(
+            "Should produce InputOutput(TimedOut) error. Got {:?} instead",
+            r
+        ),
+    };
 
     proxy.quit().await?;
+
     Ok(val)
 }
 
@@ -1011,7 +1017,7 @@ async fn iface_and_proxy_(#[allow(unused)] p2p: bool) {
         service_conn_builder
     );
     let (next_tx, mut next_rx) = channel(64);
-    let iface = MyIfaceImpl::new(next_tx.clone());
+    let iface = MyIface::new(next_tx.clone());
     let service_conn_builder = service_conn_builder
         .serve_at("/org/freedesktop/MyService", iface)
         .unwrap()
@@ -1019,9 +1025,13 @@ async fn iface_and_proxy_(#[allow(unused)] p2p: bool) {
         .unwrap();
     debug!("ObjectServer set-up.");
 
-    let (service_conn, client_conn) =
-        futures_util::try_join!(service_conn_builder.build(), client_conn_builder.build(),)
-            .unwrap();
+    let (service_conn, client_conn) = futures_util::try_join!(
+        service_conn_builder.build(),
+        client_conn_builder
+            .method_timeout(Duration::from_millis(100))
+            .build(),
+    )
+    .unwrap();
     debug!("Client connection created: {:?}", client_conn);
     debug!("Service connection created: {:?}", service_conn);
 
@@ -1034,7 +1044,7 @@ async fn iface_and_proxy_(#[allow(unused)] p2p: bool) {
     listen.await;
     debug!("Child task signaled it's ready.");
 
-    let iface: InterfaceRef<MyIfaceImpl> = service_conn
+    let iface: InterfaceRef<MyIface> = service_conn
         .object_server()
         .interface("/org/freedesktop/MyService")
         .await
@@ -1042,15 +1052,13 @@ async fn iface_and_proxy_(#[allow(unused)] p2p: bool) {
     iface
         .get()
         .await
-        .count_changed(iface.signal_context())
+        .count_changed(iface.signal_emitter())
         .await
         .unwrap();
     debug!("`PropertiesChanged` emitted for `Count` property.");
 
     loop {
-        MyIfaceImpl::alert_count(iface.signal_context(), 51)
-            .await
-            .unwrap();
+        iface.alert_count(51).await.unwrap();
         debug!("`AlertCount` signal emitted.");
 
         match next_rx.recv().await.unwrap() {
@@ -1059,7 +1067,7 @@ async fn iface_and_proxy_(#[allow(unused)] p2p: bool) {
                 let path = format!("/zbus/test/{key}");
                 service_conn
                     .object_server()
-                    .at(path.clone(), MyIfaceImpl::new(next_tx.clone()))
+                    .at(path.clone(), MyIface::new(next_tx.clone()))
                     .await
                     .unwrap();
                 debug!("Object `{path}` added.");
@@ -1068,7 +1076,7 @@ async fn iface_and_proxy_(#[allow(unused)] p2p: bool) {
                 let path = format!("/zbus/test/{key}");
                 service_conn
                     .object_server()
-                    .remove::<MyIfaceImpl, _>(path.clone())
+                    .remove::<MyIface, _>(path.clone())
                     .await
                     .unwrap();
                 debug!("Object `{path}` removed.");
